@@ -52,7 +52,7 @@ void eraC2tcio(double rc2i[3][3], double era, double rpom[3][3],
 **     McCarthy, D. D., Petit, G. (eds.), 2004, IERS Conventions (2003),
 **     IERS Technical Note No. 32, BKG
 **
-**  This revision:  2013 August 24
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -66,7 +66,7 @@ void eraC2tcio(double rc2i[3][3], double era, double rpom[3][3],
    eraRz(era, r);
    eraRxr(rpom, r, rc2t);
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
