@@ -1,4 +1,5 @@
 #include "erfa.h"
+#include "erfam.h"
 #include <string.h>
 
 int eraD2dtf(const char *scale, int ndp, double d1, double d2,
@@ -71,7 +72,7 @@ int eraD2dtf(const char *scale, int ndp, double d1, double d2,
 **     eraD2tf      decompose days to hms
 **     eraDat       delta(AT) = TAI-UTC
 **
-**  This revision:  2021 February 12
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -182,6 +183,8 @@ int eraD2dtf(const char *scale, int ndp, double d1, double d2,
 /* Status. */
    return js;
 
+/* Finished. */
+
 }
 /*----------------------------------------------------------------------
 **  
