@@ -1,4 +1,5 @@
 #include "erfa.h"
+#include "erfam.h"
 
 double eraDtdb(double date1, double date2,
                double ut, double elong, double u, double v)
@@ -157,7 +158,7 @@ double eraDtdb(double date1, double date2,
 **     Simon, J.L., Bretagnon, P., Chapront, J., Chapront-Touze, M.,
 **     Francou, G. & Laskar, J., Astron.Astrophys., 282, 663-683 (1994).
 **
-**  This revision:  2018 January 2
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -1159,6 +1160,8 @@ double eraDtdb(double date1, double date2,
 
    return w;
 
+/* Finished. */
+
 }
 /*----------------------------------------------------------------------
 **  
