@@ -1,4 +1,5 @@
 #include "erfa.h"
+#include "erfam.h"
 
 double eraEpb(double dj1, double dj2)
 /*
@@ -26,7 +27,7 @@ double eraEpb(double dj1, double dj2)
 **
 **     Lieske, J.H., 1979. Astron.Astrophys., 73, 282.
 **
-**  This revision:  2013 August 21
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -37,6 +38,8 @@ double eraEpb(double dj1, double dj2)
 
    return 1900.0 + ((dj1 - ERFA_DJ00) + (dj2 + D1900)) / ERFA_DTY;
 
+/* Finished. */
+
 }
 /*----------------------------------------------------------------------
 **  
