@@ -50,7 +50,7 @@ void eraFw2xy(double gamb, double phib, double psi, double eps,
 **
 **     Hilton, J. et al., 2006, Celest.Mech.Dyn.Astron. 94, 351
 **
-**  This revision:  2013 September 2
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -65,7 +65,7 @@ void eraFw2xy(double gamb, double phib, double psi, double eps,
 /* Extract CIP X,Y. */
    eraBpn2xy(r, x, y);
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
