@@ -1,4 +1,5 @@
 #include "erfa.h"
+#include "erfam.h"
 
 int eraGd2gce ( double a, double f, double elong, double phi,
                 double height, double xyz[3] )
@@ -55,7 +56,7 @@ int eraGd2gce ( double a, double f, double elong, double phi,
 **     P. Kenneth Seidelmann (ed), University Science Books (1992),
 **     Section 4.22, p202.
 **
-**  This revision:  2013 June 18
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -83,6 +84,8 @@ int eraGd2gce ( double a, double f, double elong, double phi,
 /* Success. */
    return 0;
 
+/* Finished. */
+
 }
 /*----------------------------------------------------------------------
 **  
