@@ -1,4 +1,5 @@
 #include "erfa.h"
+#include "erfam.h"
 
 double eraGmst00(double uta, double utb, double tta, double ttb)
 /*
@@ -68,7 +69,7 @@ double eraGmst00(double uta, double utb, double tta, double ttb)
 **     McCarthy, D. D., Petit, G. (eds.), IERS Conventions (2003),
 **     IERS Technical Note No. 32, BKG (2004)
 **
-**  This revision:  2020 November 17
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -91,6 +92,8 @@ double eraGmst00(double uta, double utb, double tta, double ttb)
 
    return gmst;
 
+/* Finished. */
+
 }
 /*----------------------------------------------------------------------
 **  
