@@ -55,7 +55,7 @@ void eraH2fk5(double rh, double dh,
 **
 **     F.Mignard & M.Froeschle, Astron.Astrophys., 354, 732-739 (2000).
 **
-**  This revision:  2017 October 12
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -92,7 +92,7 @@ void eraH2fk5(double rh, double dh,
 /* FK5 pv-vector to spherical. */
    eraPvstar(pv5, r5, d5, dr5, dd5, px5, rv5);
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
