@@ -11,7 +11,7 @@ void eraIr(double r[3][3])
 **  Returned:
 **     r       double[3][3]    r-matrix
 **
-**  This revision:  2013 June 18
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -27,7 +27,7 @@ void eraIr(double r[3][3])
    r[2][1] = 0.0;
    r[2][2] = 1.0;
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
