@@ -52,7 +52,7 @@ void eraNum00a(double date1, double date2, double rmatn[3][3])
 **     P. Kenneth Seidelmann (ed), University Science Books (1992),
 **     Section 3.222-3 (p114).
 **
-**  This revision:  2020 November 27
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -65,7 +65,7 @@ void eraNum00a(double date1, double date2, double rmatn[3][3])
    eraPn00a(date1, date2,
             &dpsi, &deps, &epsa, rb, rp, rbp, rmatn, rbpn);
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
