@@ -41,7 +41,7 @@ void eraNumat(double epsa, double dpsi, double deps, double rmatn[3][3])
 **     P. Kenneth Seidelmann (ed), University Science Books (1992),
 **     Section 3.222-3 (p114).
 **
-**  This revision:  2013 June 18
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -53,7 +53,7 @@ void eraNumat(double epsa, double dpsi, double deps, double rmatn[3][3])
    eraRz(-dpsi, rmatn);
    eraRx(-(epsa + deps), rmatn);
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
