@@ -19,7 +19,7 @@ void eraPpp(double a[3], double b[3], double apb[3])
 **     It is permissible to re-use the same array for any of the
 **     arguments.
 **
-**  This revision:  2013 June 18
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -29,7 +29,7 @@ void eraPpp(double a[3], double b[3], double apb[3])
    apb[1] = a[1] + b[1];
    apb[2] = a[2] + b[2];
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
