@@ -34,7 +34,7 @@ void eraPv2s(double pv[2][3],
 **  2) If the position is a pole, theta, td and pd are indeterminate.
 **     In such cases zeroes are returned for all three.
 **
-**  This revision:  2013 June 18
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -88,7 +88,7 @@ void eraPv2s(double pv[2][3],
    *r = rtrue;
    *rd = (rw != 0.0) ? (xyp + z*zd) / rw : 0.0;
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
