@@ -15,7 +15,7 @@ void eraS2c(double theta, double phi, double c[3])
 **  Returned:
 **     c        double[3]    direction cosines
 **
-**  This revision:  2013 June 18
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -29,7 +29,7 @@ void eraS2c(double theta, double phi, double c[3])
    c[1] = sin(theta) * cp;
    c[2] = sin(phi);
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
