@@ -1,4 +1,5 @@
 #include "erfa.h"
+#include "erfam.h"
 
 double eraSp00(double date1, double date2)
 /*
@@ -47,7 +48,7 @@ double eraSp00(double date1, double date2)
 **     McCarthy, D. D., Petit, G. (eds.), IERS Conventions (2003),
 **     IERS Technical Note No. 32, BKG (2004)
 **
-**  This revision:  2013 June 18
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -64,6 +65,8 @@ double eraSp00(double date1, double date2)
 
    return sp;
 
+/* Finished. */
+
 }
 /*----------------------------------------------------------------------
 **  
