@@ -18,7 +18,7 @@ void eraSxp(double s, double p[3], double sp[3])
 **  Note:
 **     It is permissible for p and sp to be the same array.
 **
-**  This revision:  2013 June 18
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -28,7 +28,7 @@ void eraSxp(double s, double p[3], double sp[3])
    sp[1] = s * p[1];
    sp[2] = s * p[2];
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
