@@ -20,7 +20,7 @@ void eraTr(double r[3][3], double rt[3][3])
 **  Called:
 **     eraCr        copy r-matrix
 **
-**  This revision:  2013 June 18
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -37,7 +37,7 @@ void eraTr(double r[3][3], double rt[3][3])
    }
    eraCr(wm, rt);
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
