@@ -22,7 +22,7 @@ void eraTrxp(double r[3][3], double p[3], double trp[3])
 **     eraTr        transpose r-matrix
 **     eraRxp       product of r-matrix and p-vector
 **
-**  This revision:  2020 May 24
+**  This revision:  2021 May 11
 **
 **  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
@@ -37,7 +37,7 @@ void eraTrxp(double r[3][3], double p[3], double trp[3])
 /* Matrix tr * vector p -> vector trp. */
    eraRxp(tr, p, trp);
 
-   return;
+/* Finished. */
 
 }
 /*----------------------------------------------------------------------
