@@ -1,4 +1,5 @@
 #include "erfa.h"
+#include "erfam.h"
 
 int eraUtctai(double utc1, double utc2, double *tai1, double *tai2)
 /*
@@ -58,7 +59,9 @@ int eraUtctai(double utc1, double utc2, double *tai1, double *tai2)
 **     Explanatory Supplement to the Astronomical Almanac,
 **     P. Kenneth Seidelmann (ed), University Science Books (1992)
 **
-**  Copyright (C) 2013-2015, NumFOCUS Foundation.
+**  This revision:  2021 May 11
+**
+**  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
 */
 {
@@ -66,8 +69,9 @@ int eraUtctai(double utc1, double utc2, double *tai1, double *tai2)
    int iy, im, id, j, iyt, imt, idt;
    double u1, u2, fd, dat0, dat12, w, dat24, dlod, dleap, z1, z2, a2;
 
+
 /* Put the two parts of the UTC into big-first order. */
-   big1 = ( utc1 >= utc2 );
+   big1 = ( fabs(utc1) >= fabs(utc2) );
    if ( big1 ) {
       u1 = utc1;
       u2 = utc2;
@@ -120,11 +124,13 @@ int eraUtctai(double utc1, double utc2, double *tai1, double *tai2)
 /* Status. */
    return j;
 
+/* Finished. */
+
 }
 /*----------------------------------------------------------------------
 **  
 **  
-**  Copyright (C) 2013-2015, NumFOCUS Foundation.
+**  Copyright (C) 2013-2021, NumFOCUS Foundation.
 **  All rights reserved.
 **  
 **  This library is derived, with permission, from the International
